==> nomachine-7.9.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXConsole.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXConsole;no warnings;($consoleInitFD=(-(0x031f+ 4407-0x1455)));($buffer
=(""));($console=(-(0x0f8b+ 250-0x1084)));($consoleChildOUT=(-
(0x1b30+ 491-0x1d1a)));($consoleChildIN=(-(0x0294+ 4182-0x12e9)));sub 
__initConsole{if (consoleRuning ()){Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x61\x6c\x72\x65\x61\x64\x79\x20\x72\x75\x6e\x6e\x69\x6e\x67\x20\x77\x69\x74\x68\x20\x46\x44\x23"
.$consoleInitFD));return;}($buffer=("\x20" x (0x133c+ 1079-0x1673)));my (
$consoleDescriptorError);(my $consoleInitFD=createConsoleDescriptor ((
\$consoleDescriptorError),(\$buffer),(0x08c8+ 3052-0x13b4)));(
$NXConsole::consoleInitFD=$consoleInitFD);if (($NXConsole::consoleInitFD==(-
(0x107a+ 5184-0x24b9)))){if (((not (defined ($consoleDescriptorError)))or (
$consoleDescriptorError eq ("")))){main::node_finish_error_simple (
"\x65\x47\x55\x49\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x43\x72\x65\x61\x74\x65\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x57\x69\x74\x68\x6f\x75\x74\x52\x65\x61\x73\x6f\x6e"
);}else{main::node_finish_error_simple (
"\x65\x47\x55\x49\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x43\x72\x65\x61\x74\x65\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65"
,$consoleDescriptorError);}}else{Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x73\x74\x61\x72\x74\x65\x64\x20\x77\x69\x74\x68\x20\x46\x44\x23"
.$NXConsole::consoleInitFD));}}sub closeConsole{if (consoleRuning ()){
Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x63\x6c\x6f\x73\x69\x6e\x67\x20\x46\x44\x23"
.$consoleInitFD));main::nxclose ($consoleInitFD);($consoleInitFD=(-
(0x0acc+ 219-0x0ba6)));}}sub __setupConsole{($consolePath=libnxh::NXGetConsole (
$consoleInitFD,(\$buffer),(0x074d+ 503-0x0844)));if (($consolePath==(-
(0x129d+ 291-0x13bf)))){(my $errorString=Common::NXCore::reportErrorFromNXPL (((
"\x43\x6f\x75\x6c\x64\x20\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x20\x70\x61\x74\x68\x20\x66\x6f\x72\x20"
.$consoleInitFD)."\x2e")));main::node_finish_error_simple (
"\x65\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x47\x65\x74\x43\x6f\x6e\x73\x6f\x6c\x65\x50\x61\x74\x68"
,$errorString);}else{Logger::debug (((
"\x4e\x58\x47\x65\x74\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$consolePath)."\x2e"));}}sub __createChildInOut{($consoleChildIN=main::nxopen (
$consolePath,$NXBits::O_RDWR,(0x0bd4+ 4370-0x1ce6)));if (($consoleChildIN==(-
(0x15a5+ 1798-0x1caa)))){main::node_finish_error_simple (
"\x65\x43\x61\x6e\x6e\x6f\x74\x4f\x70\x65\x6e\x46\x69\x6c\x65",$consolePath);}(
$consoleChildOUT=main::nxopen ($consolePath,$NXBits::O_RDWR,
(0x058b+ 3224-0x1223)));if (($consoleChildOUT==(-(0x1f9f+ 900-0x2322)))){
main::node_finish_error_simple (
"\x65\x43\x61\x6e\x6e\x6f\x74\x4f\x70\x65\x6e\x46\x69\x6c\x65",$consolePath);}}
sub __setControllingChildFD{(my $setConsole=libnxh::NXConsoleSetControlling (
getConsoleChildOUT ()));if (($setConsole==(-(0x0a42+ 5772-0x20cd)))){
Common::NXCore::reportErrorFromNXPL (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x53\x65\x74\x43\x6f\x6e\x74\x72\x6f\x6c\x6c\x69\x6e\x67\x28"
.getConsoleDescriptor ())."\x29\x20\x66\x61\x69\x6c\x65\x64\x2e"));}
Logger::debug (((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x3a\x3a\x5f\x5f\x73\x65\x74\x43\x6f\x6e\x74\x72\x6f\x6c\x6c\x69\x6e\x67\x43\x68\x69\x6c\x64\x46\x44\x28"
.getConsoleDescriptor ()).("\x29\x20\x72\x65\x74\x75\x72\x6e\x20".$setConsole)))
;}sub __setInheritableChildFD{Common::NXCore::nxDescriptorInheritable (
getConsoleChildIN (),(0x1333+ 691-0x15e6));
Common::NXCore::nxDescriptorInheritable (getConsoleChildOUT (),
(0x1079+ 2590-0x1a97));}sub createConsole{__initConsole ();__setupConsole ();
__createChildInOut ();__setControllingChildFD ();__setInheritableChildFD ();}sub
 getConsoleDescriptor{return ($consoleInitFD);}sub getConsoleChildIN{return (
$consoleChildIN);}sub getConsoleChildOUT{return ($consoleChildOUT);}sub 
createConsoleDescriptor{(my $ref_errorMessag=shift (@_));(my $buffer=shift (@_))
;(my $size=shift (@_));(my ($package,$filename,$line,$sub)=caller (
(0x052c+ 8299-0x2596)));if (($sub eq (""))){($sub=$package);}if ((not ((defined 
($buffer)||(!defined ($size)))))){Logger::error (((((((
"\x63\x72\x65\x61\x74\x65\x43\x6f\x6e\x73\x6f\x6c\x65\x44\x65\x73\x63\x72\x69\x70\x74\x6f\x72\x3a\x20\x69\x6e\x76\x61\x6c\x69\x64\x20\x63\x61\x6c\x6c\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e\x20\x42\x75\x66\x66\x65\x72\x20\x3d\x20").$buffer).
"\x2c\x20\x73\x69\x7a\x65\x20\x3d\x20").$size)."\x2e"));nxexit ();}Logger::debug
 (((
"\x43\x72\x65\x61\x74\x69\x6e\x67\x20\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e"));(my $ret=libnxh::NXConsole ($buffer,$size));(my $error=
libnxh::NXGetErrorName ());($$ref_errorMessag=libnxh::NXGetErrorString ());if ((
$ret==(-(0x0490+ 761-0x0788)))){Common::NXCore::reportErrorFromNXPL (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x61\x69\x6c\x65\x64\x20\x74\x6f\x20\x63\x72\x65\x61\x74\x65\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e"));return ($ret);}Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x3a\x20\x46\x44\x23"
.$ret)."\x2e"));Common::NXCore::nxDescriptorInheritable ($ret,
(0x0153+ 2702-0x0be1));Common::NXCore::closeSocketAtFinish ($ret);return ($ret);
}sub consoleRuning{if (($consoleInitFD==(-(0x1ff9+ 855-0x234f)))){return (
(0x028f+ 8166-0x2275));}return ((0x0a24+ 3698-0x1895));}"\x3f\x3f\x3f";

==> nomachine-7.10.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXConsole.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXConsole;no warnings;($consoleInitFD=(-(0x0bcc+ 5435-0x2106)));($buffer
=(""));($console=(-(0x1ddb+ 382-0x1f58)));($consoleChildOUT=(-
(0x0f17+ 5567-0x24d5)));($consoleChildIN=(-(0x1196+ 750-0x1483)));sub 
__initConsole{if (consoleRuning ()){Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x61\x6c\x72\x65\x61\x64\x79\x20\x72\x75\x6e\x6e\x69\x6e\x67\x20\x77\x69\x74\x68\x20\x46\x44\x23"
.$consoleInitFD));return;}($buffer=("\x20" x (0x0f11+ 1903-0x1580)));my (
$consoleDescriptorError);(my $consoleInitFD=createConsoleDescriptor ((
\$consoleDescriptorError),(\$buffer),(0x195f+ 1353-0x1da8)));(
$NXConsole::consoleInitFD=$consoleInitFD);if (($NXConsole::consoleInitFD==(-
(0x2072+ 188-0x212d)))){if (((not (defined ($consoleDescriptorError)))or (
$consoleDescriptorError eq ("")))){main::node_finish_error_simple (
"\x65\x47\x55\x49\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x43\x72\x65\x61\x74\x65\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x57\x69\x74\x68\x6f\x75\x74\x52\x65\x61\x73\x6f\x6e"
);}else{main::node_finish_error_simple (
"\x65\x47\x55\x49\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x43\x72\x65\x61\x74\x65\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65"
,$consoleDescriptorError);}}else{Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x73\x74\x61\x72\x74\x65\x64\x20\x77\x69\x74\x68\x20\x46\x44\x23"
.$NXConsole::consoleInitFD));}}sub closeConsole{if (consoleRuning ()){
Logger::debug ((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x63\x6c\x6f\x73\x69\x6e\x67\x20\x46\x44\x23"
.$consoleInitFD));main::nxclose ($consoleInitFD);($consoleInitFD=(-
(0x009a+ 7420-0x1d95)));}}sub __setupConsole{($consolePath=libnxh::NXGetConsole 
($consoleInitFD,(\$buffer),(0x1aa7+ 771-0x1caa)));if (($consolePath==(-
(0x1333+ 2172-0x1bae)))){(my $errorString=Common::NXCore::reportErrorFromNXPL ((
(
"\x43\x6f\x75\x6c\x64\x20\x6e\x6f\x74\x20\x67\x65\x74\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x20\x70\x61\x74\x68\x20\x66\x6f\x72\x20"
.$consoleInitFD)."\x2e")));main::node_finish_error_simple (
"\x65\x43\x6f\x75\x6c\x64\x4e\x6f\x74\x47\x65\x74\x43\x6f\x6e\x73\x6f\x6c\x65\x50\x61\x74\x68"
,$errorString);}else{Logger::debug (((
"\x4e\x58\x47\x65\x74\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x20"
.$consolePath)."\x2e"));}}sub __createChildInOut{($consoleChildIN=main::nxopen (
$consolePath,$NXBits::O_RDWR,(0x081b+ 6374-0x2101)));if (($consoleChildIN==(-
(0x09e6+ 5216-0x1e45)))){main::node_finish_error_simple (
"\x65\x43\x61\x6e\x6e\x6f\x74\x4f\x70\x65\x6e\x46\x69\x6c\x65",$consolePath);}(
$consoleChildOUT=main::nxopen ($consolePath,$NXBits::O_RDWR,
(0x0890+ 3878-0x17b6)));if (($consoleChildOUT==(-(0x1ad8+ 843-0x1e22)))){
main::node_finish_error_simple (
"\x65\x43\x61\x6e\x6e\x6f\x74\x4f\x70\x65\x6e\x46\x69\x6c\x65",$consolePath);}}
sub __setControllingChildFD{(my $setConsole=libnxh::NXConsoleSetControlling (
getConsoleChildOUT ()));if (($setConsole==(-(0x0660+ 4938-0x19a9)))){
Common::NXCore::reportErrorFromNXPL (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x53\x65\x74\x43\x6f\x6e\x74\x72\x6f\x6c\x6c\x69\x6e\x67\x28"
.getConsoleDescriptor ())."\x29\x20\x66\x61\x69\x6c\x65\x64\x2e"));}
Logger::debug (((
"\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x3a\x3a\x5f\x5f\x73\x65\x74\x43\x6f\x6e\x74\x72\x6f\x6c\x6c\x69\x6e\x67\x43\x68\x69\x6c\x64\x46\x44\x28"
.getConsoleDescriptor ()).("\x29\x20\x72\x65\x74\x75\x72\x6e\x20".$setConsole)))
;}sub __setInheritableChildFD{Common::NXCore::nxDescriptorInheritable (
getConsoleChildIN (),(0x1091+ 5231-0x2500));
Common::NXCore::nxDescriptorInheritable (getConsoleChildOUT (),
(0x0d37+ 759-0x102e));}sub createConsole{__initConsole ();__setupConsole ();
__createChildInOut ();__setControllingChildFD ();__setInheritableChildFD ();}sub
 getConsoleDescriptor{return ($consoleInitFD);}sub getConsoleChildIN{return (
$consoleChildIN);}sub getConsoleChildOUT{return ($consoleChildOUT);}sub 
createConsoleDescriptor{(my $ref_errorMessag=shift (@_));(my $buffer=shift (@_))
;(my $size=shift (@_));(my ($package,$filename,$line,$sub)=caller (
(0x0407+ 5463-0x195d)));if (($sub eq (""))){($sub=$package);}if ((not ((defined 
($buffer)||(!defined ($size)))))){Logger::error (((((((
"\x63\x72\x65\x61\x74\x65\x43\x6f\x6e\x73\x6f\x6c\x65\x44\x65\x73\x63\x72\x69\x70\x74\x6f\x72\x3a\x20\x69\x6e\x76\x61\x6c\x69\x64\x20\x63\x61\x6c\x6c\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e\x20\x42\x75\x66\x66\x65\x72\x20\x3d\x20").$buffer).
"\x2c\x20\x73\x69\x7a\x65\x20\x3d\x20").$size)."\x2e"));nxexit ();}Logger::debug
 (((
"\x43\x72\x65\x61\x74\x69\x6e\x67\x20\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e"));(my $ret=libnxh::NXConsole ($buffer,$size));(my $error=
libnxh::NXGetErrorName ());($$ref_errorMessag=libnxh::NXGetErrorString ());if ((
$ret==(-(0x17f0+ 2119-0x2036)))){Common::NXCore::reportErrorFromNXPL (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x61\x69\x6c\x65\x64\x20\x74\x6f\x20\x63\x72\x65\x61\x74\x65\x20\x63\x6f\x6e\x73\x6f\x6c\x65\x20\x66\x72\x6f\x6d\x20"
.$sub)."\x2e"));return ($ret);}Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x3a\x3a\x4e\x58\x43\x6f\x6e\x73\x6f\x6c\x65\x20\x72\x65\x74\x75\x72\x6e\x65\x64\x3a\x20\x46\x44\x23"
.$ret)."\x2e"));Common::NXCore::nxDescriptorInheritable ($ret,
(0x0747+ 230-0x082d));Common::NXCore::closeSocketAtFinish ($ret);return ($ret);}
sub consoleRuning{if (($consoleInitFD==(-(0x1586+ 4117-0x259a)))){return (
(0x1240+ 3194-0x1eba));}return ((0x06ca+ 5413-0x1bee));}"\x3f\x3f\x3f";
